import type { ComponentStackFrame } from '../../helpers/parse-component-stack';
/**
 *
 * Format component stack into pseudo HTML
 * component stack is an array of strings, e.g.: ['p', 'p', 'Page', ...]
 *
 * For html tags mismatch, it will render it for the code block
 *
 * <pre>
 *  <code>{`
 *    <Page>
 *       <p>
 *       ^^^
 *         <p>
 *         ^^^
 *  `}</code>
 * </pre>
 *
 * For text mismatch, it will render it for the code block
 *
 * <pre>
 * <code>{`
 *   <Page>
 *     <p>
 *       "Server Text" (red text as removed)
 *       "Client Text" (green text as added)
 *     </p>
 *   </Page>
 * `}</code>
 *
 *
 */
export declare function PseudoHtmlDiff({ componentStackFrames, serverContent, clientContent, hydrationMismatchType, ...props }: {
    componentStackFrames: ComponentStackFrame[];
    serverContent: string;
    clientContent: string;
    [prop: string]: any;
    hydrationMismatchType: 'tag' | 'text';
}): import("react/jsx-runtime").JSX.Element;
